==> epyk-1.3.9-py2.py3-none-any.whl: epyk/core/js/html/JsHtmlStars.py <==

from epyk.core.js.html import JsHtml
from epyk.core.js.primitives import JsObjects


class Stars(JsHtml.JsHtmlRich):

  @property
  def val(self):
    """
    Description:
    ------------
    The Javascript data object. A dictionary with all the specific metadata attached to the component
    """
    return JsObjects.JsObjects.get(
      "{%s: {value: %s.dataset.level, timestamp: Date.now(), offset: new Date().getTimezoneOffset()}}" % (self.htmlCode, self.varName))

  @property
  def content(self):
    """
    Description:
    ------------
    The Javascript value of the component. This returned only a value corresponding to the state of the component
    """
    return JsHtml.ContentFormatters(self._report, "%s.dataset.level" % self.varName)


class Slides(JsHtml.JsHtmlRich):

  @property
  def content(self):
    """
    Description:
    ------------
    The Javascript value of the component. This returned only a value corresponding to the state of the component
    """
    return JsHtml.ContentFormatters(self._report, "%s.getAttribute('data-current_slide')" % self.varName)

  def goTo(self, number):
    """
    Description:
    ------------

    TODO: ADD if in the JavaScript to display the next and previous if goTo triggered from first or last slides
    :param number:
    """
    return JsObjects.JsObjects.get('''%s.setAttribute('data-current_slide', Math.min(%s, %s)-2);
      %s ''' % (self.varName, number, len(self._src.val), self._src.next.dom.events.trigger('click')))

==> epyk-1.5.0-py2.py3-none-any.whl: epyk/core/js/html/JsHtmlStars.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

from epyk.core.js.html import JsHtml
from epyk.core.js.primitives import JsObjects


class Stars(JsHtml.JsHtmlRich):

  @property
  def val(self):
    """
    Description:
    ------------
    The Javascript data object. A dictionary with all the specific metadata attached to the component.

    Usage:
    -----
    """
    return JsObjects.JsObjects.get(
      "{%s: {value: %s.dataset.level, timestamp: Date.now(), offset: new Date().getTimezoneOffset()}}" % (self.htmlCode, self.varName))

  @property
  def content(self):
    """
    Description:
    ------------
    The Javascript value of the component. This returned only a value corresponding to the state of the component.

    Usage:
    -----
    """
    return JsHtml.ContentFormatters(self._report, "%s.dataset.level" % self.varName)


class Slides(JsHtml.JsHtmlRich):

  @property
  def content(self):
    """
    Description:
    ------------
    The Javascript value of the component. This returned only a value corresponding to the state of the component.

    Usage:
    -----
    """
    return JsHtml.ContentFormatters(self._report, "%s.getAttribute('data-current_slide')" % self.varName)

  def goTo(self, number):
    """
    Description:
    ------------

    TODO: ADD if in the JavaScript to display the next and previous if goTo triggered from first or last slides.

    Usage:
    -----

    Attributes:
    ----------
    :param number: Integer.
    """
    return JsObjects.JsObjects.get('''%s.setAttribute('data-current_slide', Math.min(%s, %s)-2);
      %s ''' % (self.varName, number, len(self._src.val), self._src.next.dom.events.trigger('click')))
